Improve this doc

# `ngMockE2E`

The `ngMockE2E` is an angular module which contains mocks suitable for end-to-end testing. Currently there is only one mock present in this module - the e2e $httpBackend mock.

## Installation

First include `angular-mocke2e.js` in your HTML:

        <script src="angular.js">
        <script src="angular-mocke2e.js">

You can download this file from the following places:

- Google CDN
  e.g. `//ajax.googleapis.com/ajax/libs/angularjs/X.Y.Z/angular-mocke2e.js`
- Bower
  e.g.

      bower install angular-mocke2e@X.Y.Z

- code.angularjs.org
  e.g.

      "//code.angularjs.org/X.Y.Z/angular-mocke2e.js"

where X.Y.Z is the AngularJS version you are running.

Then load the module in your application by adding it as a dependent module:

      angular.module('app', ['ngMockE2E']);

With that you're ready to get started!

## Module Components

### Service

Name | Description
--- | ---
$httpBackend | Fake HTTP backend implementation suitable for end-to-end testing or backend-less development of applications that use the $http service.